import React from 'react';
import { PopoverProps } from '@patternfly/react-core';
export interface ChatbotFootnoteProps extends React.HTMLProps<HTMLDivElement> {
    /** Label to show for the footnote */
    label: string;
    /** Config for the popover which opens up when footnote is clicked */
    popover?: ChatbotFootnotePopover;
    /** Custom classname for the Footnote component */
    className?: string;
}
export interface ChatbotFootnotePopover {
    /** Title for the Footnote popover */
    title: string;
    /** Description for the Footnote popover */
    description: string;
    /** Optional Banner Image that can be shown in the Footnote Popover */
    bannerImage?: ChatbotFootnotePopoverBannerImage;
    /** Optional CTA button that can be used to trigger an action and close the popover */
    cta?: ChatbotFootnotePopoverCTA;
    /** Optional link that can be used to show an external link like **View AI policy** */
    link?: ChatbotFootnotePopoverLink;
    /** Props for PF Popover */
    popoverProps?: PopoverProps;
}
export interface ChatbotFootnotePopoverCTA {
    /** Label for the CTA */
    label: string;
    /** Callback for the CTA */
    onClick: () => void;
}
export interface ChatbotFootnotePopoverBannerImage {
    /** Source for the banner image */
    src: string;
    /** Alternate text for the banner image */
    alt: string;
}
export interface ChatbotFootnotePopoverLink {
    /** Label for the Link */
    label: string;
    /** URL for the Link */
    url: string;
}
export declare const ChatbotFootnote: React.FunctionComponent<ChatbotFootnoteProps>;
export default ChatbotFootnote;
