import React from 'react';
import { CardProps, LabelGroupProps, OUIAProps } from '@patternfly/react-core';
import QuickResponse from '../QuickResponse/QuickResponse';
export interface UserFeedbackProps extends Omit<CardProps, 'onSubmit'>, OUIAProps {
    /** Additional classes for the pagination navigation container. */
    className?: string;
    /** Quick responses a user can select */
    quickResponses?: QuickResponse[];
    /** Props for quick responses container */
    quickResponseContainerProps?: Omit<LabelGroupProps, 'ref'>;
    /** Whether form includes text area */
    hasTextArea?: boolean;
    /** Placeholder of text area */
    textAreaPlaceholder?: string;
    /** Aria label for text area */
    textAreaAriaLabel?: string;
    /** Callback function for when text area changes */
    onTextAreaChange?: (event: React.ChangeEvent<HTMLTextAreaElement>, value: string) => void;
    /** Callback function for when form is submitted */
    onSubmit: (selectedResponse?: string, additionalFeedback?: string) => void;
    /** Callback function for when close button is clicked */
    onClose: () => void;
    /** Aria label for close button */
    closeButtonAriaLabel?: string;
    /** Label for the English word "Submit." */
    submitWord?: string;
    /** @deprecated Cancel button has been deprecated. Use the close button instead. Label for the English word "Cancel." */
    cancelWord?: string;
    /** Uniquely identifies the card. */
    id?: string;
    /** The heading level to use, default is h1 */
    headingLevel?: 'h1' | 'h2' | 'h3' | 'h4' | 'h5' | 'h6';
    /** Whether to focus card on load */
    focusOnLoad?: boolean;
    /** Timestamp passed in by Message for more context in aria announcements */
    timestamp?: string;
}
declare const UserFeedback: React.FunctionComponent<UserFeedbackProps>;
export default UserFeedback;
