import React from 'react';
import { ButtonProps, TooltipProps } from '@patternfly/react-core';
export interface MicrophoneButtonProps extends ButtonProps {
    /** Boolean check if the browser is listening to speech or not */
    isListening: boolean;
    /** Class name for MicrophoneButton */
    className?: string;
    /** Callback to update the value of isListening */
    onIsListeningChange: React.Dispatch<React.SetStateAction<boolean>>;
    /** Callback to update the message value once speech recognition is complete */
    onSpeechRecognition: React.Dispatch<React.SetStateAction<string>>;
    /** Props to control the PF Tooltip component */
    tooltipProps?: Omit<TooltipProps, 'content'>;
    /** English text "Use microphone" and "Stop listening" used in the tooltip */
    tooltipContent?: {
        active?: string;
        inactive?: string;
    };
    /** Locale code for language speech recognition is conducted in. This should be in the format 'en-US', a.k.a. the ISO 639-1 code, a dash, and the ISO_3166-1 code. */
    language?: string;
}
export declare const MicrophoneButton: React.FunctionComponent<MicrophoneButtonProps>;
export default MicrophoneButton;
