"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_2 = require("@testing-library/react");
require("@testing-library/jest-dom");
const user_event_1 = __importDefault(require("@testing-library/user-event"));
const StopButton_1 = require("./StopButton");
const renderStop = (props) => {
    const spy = jest.fn();
    (0, react_2.render)(react_1.default.createElement(StopButton_1.StopButton, Object.assign({ onClick: spy }, props)));
};
describe('Stop button', () => {
    it('should render button correctly', () => {
        renderStop();
        expect(react_2.screen.getByRole('button', { name: 'Stop button' })).toBeTruthy();
    });
    it('should handle onClick correctly', () => __awaiter(void 0, void 0, void 0, function* () {
        const spy = jest.fn();
        (0, react_2.render)(react_1.default.createElement(StopButton_1.StopButton, { onClick: spy }));
        yield user_event_1.default.click(react_2.screen.getByRole('button', { name: 'Stop button' }));
        expect(react_2.screen.getByRole('tooltip', { name: 'Stop' })).toBeTruthy();
        expect(spy).toHaveBeenCalledTimes(1);
    }));
    it('should handle custom tooltip correctly', () => __awaiter(void 0, void 0, void 0, function* () {
        (0, react_2.render)(react_1.default.createElement(StopButton_1.StopButton, { onClick: jest.fn, tooltipContent: "Test" }));
        yield user_event_1.default.click(react_2.screen.getByRole('button', { name: 'Stop button' }));
        expect(react_2.screen.getByRole('tooltip', { name: 'Test' })).toBeTruthy();
    }));
    it('should handle className prop', () => {
        renderStop({ className: 'test' });
        expect(react_2.screen.getByRole('button', { name: 'Stop button' })).toHaveClass('test');
    });
    it('should handle spread props, including aria-label', () => {
        renderStop({ 'aria-label': 'test' });
        expect(react_2.screen.getByRole('button', { name: 'test' }));
    });
    it('should handle tooltipProps prop', () => __awaiter(void 0, void 0, void 0, function* () {
        renderStop({ tooltipProps: { id: 'test' } });
        yield user_event_1.default.click(react_2.screen.getByRole('button', { name: 'Stop button' }));
        expect(react_2.screen.getByRole('tooltip', { name: 'Stop' })).toHaveAttribute('id', 'test');
    }));
});
