"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SegmentTrackingProvider = void 0;
const analytics_next_1 = require("@segment/analytics-next");
class SegmentTrackingProvider {
    getKey() {
        return 'segmentKey';
    }
    initialize(props) {
        // eslint-disable-next-line no-console
        console.log('SegmentProvider initialize');
        const segmentKey = props.segmentKey;
        // We need to create an object here, as ts lint is unhappy otherwise
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const integrations = props.segmentIntegrations;
        this.analytics = analytics_next_1.AnalyticsBrowser.load({
            writeKey: segmentKey,
            cdnURL: props.segmentCdn
        }, {
            integrations: Object.assign({}, integrations)
        });
    }
    identify(userID) {
        // eslint-disable-next-line no-console
        console.log('SegmentProvider userID: ' + userID);
        if (this.analytics) {
            this.analytics.identify(userID);
        }
    }
    trackPageView(url) {
        // eslint-disable-next-line no-console
        console.log('SegmentProvider url', url);
        if (this.analytics) {
            if (url) {
                this.analytics.page(url);
            }
            else {
                this.analytics.page(); // Uses window.url
            }
        }
    }
    trackSingleItem(item, properties) {
        // eslint-disable-next-line no-console
        console.log('SegmentProvider: trackSingleItem' + item, properties);
        if (this.analytics) {
            this.analytics.track(item, { properties });
        }
    }
}
exports.SegmentTrackingProvider = SegmentTrackingProvider;
