var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React from 'react';
import { render, screen } from '@testing-library/react';
import '@testing-library/jest-dom';
import FileDetailsLabel from './FileDetailsLabel';
import userEvent from '@testing-library/user-event';
describe('FileDetailsLabel', () => {
    it('should render file details label', () => {
        const { container } = render(React.createElement(FileDetailsLabel, { fileName: "test.txt" }));
        expect(container).toMatchSnapshot();
    });
    it('should render file details correctly if an extension we support is passed in', () => {
        render(React.createElement(FileDetailsLabel, { fileName: "test.txt" }));
        expect(screen.getByText('test')).toBeTruthy();
        expect(screen.getByText('TEXT')).toBeTruthy();
    });
    it('should skip language if we do not support an extension', () => {
        render(React.createElement(FileDetailsLabel, { fileName: "test.joke", languageTestId: "language" }));
        expect(screen.getByText('test')).toBeTruthy();
        expect(screen.queryByTestId('language')).toBeFalsy();
    });
    it('should not show spinner by default', () => {
        render(React.createElement(FileDetailsLabel, { fileName: "test.txt", spinnerTestId: "spinner" }));
        expect(screen.queryByTestId('spinner')).toBeFalsy();
    });
    it('should show spinner if loading', () => {
        render(React.createElement(FileDetailsLabel, { fileName: "test.txt", isLoading: true, spinnerTestId: "spinner" }));
        expect(screen.getByText('test')).toBeTruthy();
        expect(screen.getByText('TEXT')).toBeTruthy();
        expect(screen.queryByTestId('spinner')).toBeTruthy();
    });
    it('should call onClick prop', () => __awaiter(void 0, void 0, void 0, function* () {
        const spy = jest.fn();
        render(React.createElement(FileDetailsLabel, { fileName: "test.txt", onClick: spy }));
        yield userEvent.click(screen.getByRole('button'));
        expect(spy).toHaveBeenCalledTimes(1);
    }));
    it('should call onClose prop', () => __awaiter(void 0, void 0, void 0, function* () {
        const spy = jest.fn();
        render(React.createElement(FileDetailsLabel, { fileName: "test.txt", onClose: spy }));
        yield userEvent.click(screen.getByRole('button', { name: /Close test.txt/i }));
        expect(spy).toHaveBeenCalledTimes(1);
    }));
    it('should use closeButtonAriaLabel prop appropriately', () => {
        render(React.createElement(FileDetailsLabel, { fileName: "test.txt", onClose: jest.fn(), closeButtonAriaLabel: "Delete file" }));
        screen.getByRole('button', { name: /Delete file/i });
    });
});
