import React from 'react';
import { CardProps, OUIAProps } from '@patternfly/react-core';
export interface UserFeedbackCompleteProps extends Omit<CardProps, 'ref'>, OUIAProps {
    /** Additional classes for the pagination navigation container. */
    className?: string;
    /** Substitute for the English phrase "Thank you". */
    title?: string;
    /** Substitute for the English phrase "You have successfully sent your feedback! Thank you for responding." */
    body?: string | React.ReactNode;
    /** Callback function for when close button is clicked */
    onClose?: () => void;
    /** Aria label for close button */
    closeButtonAriaLabel?: string;
    /** Function to be executed on timeout. Relevant when the timeout prop is set. */
    onTimeout?: () => void;
    /** If set to true, the timeout is 8000 milliseconds. If a number is provided, card will
     * be dismissed after that amount of time in milliseconds.
     */
    timeout?: number | boolean;
    /** If the user hovers over the card and `timeout` expires, this is how long to wait
     * before finally dismissing the alert.
     */
    timeoutAnimation?: number;
    /** Callback for when mouse hovers over card */
    onMouseEnter?: (e: React.MouseEvent<HTMLDivElement>) => void;
    /** Callback for when mouse stops hovering over card */
    onMouseLeave?: (e: React.MouseEvent<HTMLDivElement>) => void;
    /** Value to overwrite the randomly generated data-ouia-component-id.*/
    ouiaId?: number | string;
    /** Set the value of data-ouia-safe. Only set to true when the component is in a static state, i.e. no animations are occurring. At all other times, this value must be false. */
    ouiaSafe?: boolean;
    /** Flag to indicate if the card is in a live region. */
    isLiveRegion?: boolean;
    /** Uniquely identifies the completion card. */
    id?: string;
    /** Whether to focus card on load */
    focusOnLoad?: boolean;
    /** Timestamp passed in by Message for more context in aria announcements */
    timestamp?: string;
}
declare const UserFeedbackComplete: React.FunctionComponent<UserFeedbackCompleteProps>;
export default UserFeedbackComplete;
